@@ -1,6 +1,7 @@
 import asyncio
 from typing import Union, Mapping, TYPE_CHECKING, Dict, Any, TypeVar, List, Type, Optional
 
+from databases.backends.sqlite import SQLiteBackend
 from pydantic import BaseModel
 from pydantic.main import ModelMetaclass, UNTOUCHED_TYPES
 from sqlalchemy import select, func, Table, exists, MetaData, Column
@@ -241,13 +242,13 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         assert getattr(self, self.__pkey_name__, None) is not None
 
     # pylint: disable=access-member-before-definition
-    async def save(self):
+    async def save(self) -> MODEL:
         table = self.__table__
         pkey_name = self.__pkey_name__
         if self.__bound__:
             self.ensure_id()
             if not self.__modified__:
-                return
+                return self
             fields = self.dict(include=self.__modified__)
             # pylint: disable=access-member-before-definition
             await FoxOrm.db.execute(
@@ -257,13 +258,15 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
             self.__modified__.clear()
         else:
             data = self.dict(exclude={pkey_name}, include=self.__fields__.keys())
-            if len(data) == 0:
-                data[pkey_name] = None
             if self.pkey_value is not None:
                 data[pkey_name] = self.pkey_value
             # pylint: disable=attribute-defined-outside-init
-            self.pkey_value = await FoxOrm.db.fetch_val(table.insert().returning(self.pkey_column), data)
+            if not isinstance(FoxOrm.db.connection()._backend, SQLiteBackend):
+                self.pkey_value = await FoxOrm.db.fetch_val(table.insert().returning(self.pkey_column).values(**data))
+            else:
+                self.pkey_value = await FoxOrm.db.execute(table.insert().values(**data))
             self.__bound__ = True
+        return self
 
     @classmethod
     def _generate_query(cls, where, order_by, limit, offset):
@@ -298,7 +301,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         return res
 
     @classmethod
-    async def select_all(cls: Type[MODEL], where, values: dict = None, *,
+    async def select_all(cls: Type[MODEL], where=None, values: dict = None, *,
                          order_by=None, limit=None, offset=None, skip_parsing=False) -> List[MODEL]:
         construct_func = cls.construct if skip_parsing else cls.parse_obj
         q_res = await FoxOrm.db.fetch_all(cls._generate_query(where, order_by, limit, offset), values)
@@ -342,7 +345,7 @@ class OrmModel(BaseModel, metaclass=OrmModelMeta):
         return await FoxOrm.db.fetch_val(query, values)
 
     @classmethod
-    async def get(cls: Type[MODEL], obj_id: int, skip_parsing=False) -> MODEL:
+    async def get(cls: Type[MODEL], obj_id: int, skip_parsing=False) -> Optional[MODEL]:
         # false positive
         # pylint: disable=comparison-with-callable
         return await cls.select(cls.pkey_column == obj_id, skip_parsing=skip_parsing)
